CarouselMedia class

Constructors

CarouselMedia({required String value, required int height, required int width, required String type, int? videoProgressSec})
CarouselMedia.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
final
isImage → bool
no setter
isVideo → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
value → String
final
videoProgressSec → int?
final
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited