PdaAd class

Constructors

PdaAd({required String adUnit, required String clickTrackingUrl, required String impressionTrackingUrl, required String uclid, required String crt, required PdaElements elements, String? cliUbid})
PdaAd.fromMap(Map<String, dynamic> map)
factory

Properties

adUnit → String
final
clickTrackingUrl → String
final
cliUbid → String?
final
crt → String
final
elements → PdaElements
final
hashCode → int
The hash code for this object.
no setterinherited
impressionTrackingUrl → String
final
products → List<NativeAd>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uclid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited