PdaElements class

Constructors

PdaElements({required List<NativeAd> productList, PdaMediaElement? media, String? width, String? height, String? destinationUrl, List<CarouselCard>? carouselCards, List<ThirdPartyTracker>? thirdPartyImpressionTrackers, List<ThirdPartyTracker>? thirdPartyClickTrackers})
PdaElements.fromMap(Map<String, dynamic> map)
factory

Properties

bannerUrl → String?
Get the banner URL from media
no setter
carouselCards → List<CarouselCard>?
final
destinationUrl → String?
final
hasCarousel → bool
Check if this has carousel cards
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasThirdPartyClickTrackers → bool
Check if this has third-party click trackers
no setter
hasThirdPartyImpressionTrackers → bool
Check if this has third-party impression trackers
no setter
height → String?
final
isImage → bool
Check if this is an image type
no setter
isVideo → bool
Check if this is a video type
no setter
media → PdaMediaElement?
final
productList → List<NativeAd>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thirdPartyClickTrackers → List<ThirdPartyTracker>?
final
thirdPartyImpressionTrackers → List<ThirdPartyTracker>?
final
width → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited