ThirdPartyTracker class

Third Party Tracker - External tracking pixels/URLs for impressions and clicks Used for PDA ads to track both impression and click events

Constructors

ThirdPartyTracker({required String type, required String value, required String vendor})
ThirdPartyTracker.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
value → String
final
vendor → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited