NativeVideoRenderer class

A class to control native video playback through the VideoLoaderFlutter class.

This class provides a Flutter interface to the native VideoLoaderFlutter functionality, allowing you to control video playback, mute/unmute, and check playback state.

Constructors

NativeVideoRenderer(String videoId)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this video renderer has been disposed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoId → String
final

Methods

dispose() → Future<void>
Releases the video resources.
isMuted() → Future<bool?>
Checks if the video is currently muted.
isPlaying() → Future<bool?>
Checks if the video is currently playing.
muteUnmute() → Future<Map<String, dynamic>?>
Toggles mute/unmute state of the video.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<bool>
Pauses the video.
play() → Future<bool>
Plays the video.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required String videoId, required String videoUrl, required int width, required int height}) → Future<NativeVideoRenderer?>
Creates a NativeVideoRenderer instance with the video view.
createVideoView({required String videoId, required String videoUrl, required int width, required int height}) → Future<Map<String, dynamic>?>
Creates a video view on the native side.