VideoViewController class

Controller for VideoView to control playback from outside

Constructors

VideoViewController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<_VideoViewState>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isMuted() → Future<bool?>
isPlaying() → Future<bool?>
muteUnmute() → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
play() → Future<void>
toggleMute() → Future<void>
togglePlayPause() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited