BaseNativeAdView class

Constructors

BaseNativeAdView(BuildContext context)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenHeight → double
final
screenWidth → double
final

Methods

createHorizontalAdView({required BuildContext context, required NativeAd adData, required NativeAdType? adType, required double finalWidth, required double finalHeight, String? adLabelText, Alignment? adLabelAlignment = Alignment.topLeft, NativeAdStyle? style, Widget? customCtaView, Widget? customBadgeView}) → Widget
createNativeAdView({required Widget? contentView}) → Widget
createVerticalAdView({required BuildContext context, required NativeAd adData, required NativeAdType? adType, required double finalWidth, required double finalHeight, String? adLabelText, Alignment? adLabelAlignment = Alignment.topLeft, NativeAdStyle? style, Widget? customCtaView, Widget? customBadgeView}) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited