BasePdaAdWidget class abstract

Inheritance
Implementers

Constructors

BasePdaAdWidget({Key? key, required Map<String, dynamic>? ad, dynamic onAdClicked(Map<String, dynamic>)?, dynamic onAdLoaded(Map<String, dynamic>)?, dynamic onProductClicked(NativeAd)?})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAdClicked → dynamic Function(Map<String, dynamic>)?
final
onAdLoaded → dynamic Function(Map<String, dynamic>)?
final
onProductClicked → dynamic Function(NativeAd)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildImageElement(BuildContext context, PdaAd pdaAd, {double? width, double? height, NativeAdStyle? style, Duration autoSlideInterval = const Duration(seconds: 3), bool showIndicators = true, String? adLabelText, Alignment? adLabelAlignment, Widget? customBadgeView, VoidCallback? onBannerClicked}) Widget
Build the image element section using PDA Banner
buildPdaView(BuildContext context, PdaAd pdaAd) Widget
clampHeight(double height, BuildContext context) double
clampWidth(double width, BuildContext context) double
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getFirstProduct(PdaAd pdaAd) NativeAd?
Get the first product from product_list to display as PLA ad
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited