NativeAdStyle class

Constructors

NativeAdStyle({BoxDecoration? adLayoutStyle = defaultAdLayoutStyle, TextStyle? titleTextStyle = defaultTitleStyle, TextStyle? skuDescriptionTextStyle = defaultSkuDescriptionStyle, TextStyle? deliveryDetailTextStyle = defaultDeliveryDetailStyle, TextStyle? originalPriceTextStyle = defaultOriginalPriceStyle, TextStyle? discountedPriceTextStyle = defaultDiscountedPriceStyle, TextStyle? offerTextStyle = defaultOfferStyle, TextStyle? ratingTextStyle = defaultRatingStyle, TextStyle? ratingCountTextStyle = defaultRatingCountStyle, TextStyle? membershipPriceTextStyle = defaultMembershipStyle, String? ctaTitle, VoidCallback? ctaAction, int? mediaHeight, int? mediaWidth})

Properties

adLayoutStyle → BoxDecoration?
final
ctaAction → VoidCallback?
final
ctaTitle → String?
final
deliveryDetailTextStyle → TextStyle?
final
discountedPriceTextStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
mediaHeight → int?
final
mediaWidth → int?
final
membershipPriceTextStyle → TextStyle?
final
offerTextStyle → TextStyle?
final
originalPriceTextStyle → TextStyle?
final
ratingCountTextStyle → TextStyle?
final
ratingTextStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skuDescriptionTextStyle → TextStyle?
final
titleTextStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited