NativeAd class

Constructors

NativeAd({required String skuId, required String name, required double mrp, required String productUrl, String? storeId, String? imageUrl, String? videoUrl, double? salePrice, String? sellerId, String? itemGroupId, String? brand, String? description, String? customLabel0, String? customLabel1, String? customLabel2, String? customLabel3, String? customLabel4, String? uclid, String? categoryL1, String? categoryL2, String? categoryL3, Map? adMetadata, String? cliUbid, String? crt, required String elementsType})
NativeAd.fromMap(Map<String, dynamic> map)
factory

Properties

adMetadata → Map?
final
brand → String?
final
categoryL1 → String?
final
categoryL2 → String?
final
categoryL3 → String?
final
cliUbid → String?
final
crt → String?
final
customLabel0 → String?
final
customLabel1 → String?
final
customLabel2 → String?
final
customLabel3 → String?
final
customLabel4 → String?
final
description → String?
final
elementsType → String
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String?
final
itemGroupId → String?
final
mrp → double
final
name → String
final
productUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salePrice → double?
final
sellerId → String?
final
skuId → String
final
storeId → String?
final
uclid → String?
final
videoUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited