OsmosConfig class

Constructors

OsmosConfig({required String clientId, required bool debug, required bool shareAdvertisingId, required String displayAdsHost, required String productAdsHost, required String eventTrackingHost, required bool enableBatchProcessing, required int maxEventsPerBatch, required int maxTimeInterval, required int maxRetryCount})
OsmosConfig.fromMap(Map<String, dynamic> map)
factory

Properties

clientId → String
final
debug → bool
final
displayAdsHost → String
final
enableBatchProcessing → bool
final
eventTrackingHost → String
final
hashCode → int
The hash code for this object.
no setterinherited
maxEventsPerBatch → int
final
maxRetryCount → int
final
maxTimeInterval → int
final
productAdsHost → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareAdvertisingId → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited