OsmosSDK class

Properties

adFetcher AdFetcherInterface
latefinal
adRenderer AdRendererInterface
latefinal
bannerAdView BannerAdViewManagerInterface
latefinal
carouselAdView CarouselAdViewManagerInterface
latefinal
configMap Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
interstitialAdView InterstitialAdViewManagerInterface
latefinal
multiAdCarouselView MultiAdCarouselViewManagerInterface
latefinal
nativeAdview NativeAdViewManagerInterface
latefinal
pdaAdView PDAAdViewManagerInterface
latefinal
pipAdView PIPAdViewManagerInterface
latefinal
registerEvent RegisterEventInterface
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliderAdView SliderAdViewManagerInterface
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clientId(String clientId) ConfigBuilder
globalInstance() OsmosSDK
shutdown() → void