NativeAdViewManagerInterface class abstract

Interface for managing native advertisement views.

Provides methods for creating and configuring native ad widgets with various display settings, orientations, and event callbacks.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showAd({required Map<String, dynamic> adData, required Widget contentView, void onAdClick(Map)?, void onViewAppeared(Map, String)?}) → Widget
Creates a native ad widget with the specified configuration.
showHorizontalAd({required Map<String, dynamic> adData, NativeAdType? adType, required double width, double? height, String? adLabelText, Alignment? adLabelAlignment, Widget? customCtaView, Widget? customBadgeView, NativeAdStyle? customStyle, void onAdClick(Map)?, void onViewAppeared(Map, String)?}) → Widget
Creates a horizontal native ad widget.
showNativeAdCarousel({required Map<String, dynamic> adData, required NativeAdType? adType, required double width, double? height, double? elementWidth, double? elementHeight, String? adLabelText, Alignment? adLabelAlignment, NativeAdStyle? customStyle, Widget? customCtaView, Widget? customBadgeView, void onAdClicked(Map<String, dynamic>)?, void onViewLoad(Map<String, dynamic>)?, void errorCallback(String error)?}) → Widget
Creates a native ad carousel widget with the specified configuration.
showNativeAdCarouselFromProducts({required List<NativeAd> nativeAds, required String cliUbid, NativeAdType? adType, required double width, double? height, double? elementWidth, double? elementHeight, Axis scrollDirection = Axis.horizontal, String? adLabelText, Alignment? adLabelAlignment, NativeAdStyle? customStyle, Widget? customCtaView, Widget? customBadgeView, void onAdClicked(Map<String, dynamic>)?, void onViewLoad(Map<String, dynamic>)?}) → Widget
Creates a native ad carousel widget from a list of NativeAd objects.
showPdaAd({required Map<String, dynamic> ad, required String cliUbid, required NativeAdType adType, required double width, double? height, double? imageHeight, bool layoutHorizontal = false, double mediaRatio = 0.6, double? plaItemWidth, double? plaItemHeight, NativeAdStyle? plaCustomStyle, Widget? plaCustomCtaView, Widget? plaCustomBadgeView, String? plaAdLabelText, String? adLabelText, Alignment? adLabelAlignment, Widget? customCtaView, Widget? customBadgeView, NativeAdStyle? customStyle, void onAdClicked(Map<String, dynamic>)?, void onAdLoaded(Map<String, dynamic>)?, void onProductClicked(dynamic)?}) → Widget
Creates a PDA (Product Display Ad) widget.
showVerticalAd({required Map<String, dynamic> adData, NativeAdType? adType, required double width, double? height, String? adLabelText, Alignment? adLabelAlignment, Widget? customCtaView, Widget? customBadgeView, NativeAdStyle? customStyle, void onAdClick(Map)?, void onViewAppeared(Map, String)?}) → Widget
Creates a vertical native ad widget.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited