GeoTargeting class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

city(String city) → GeoTargeting
country(String country) → GeoTargeting
location({String? city, String? state, String? country}) → GeoTargeting
networks(List<String> networks) → GeoTargeting
state(String state) → GeoTargeting
storeIds(List<String> storeIds) → GeoTargeting