Builder class

Constructors

Builder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionType(VideoActionType value) → Builder
add(String key, dynamic value) → Builder
build() → TrackingParams
merge(Map<String, dynamic> dictionary) → Builder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
position(int? value) → Builder
productPrices(String? value) → Builder
productQuantities(String value) → Builder
sellerId(String? value) → Builder
skuId(String value) → Builder
source(String value) → Builder
storeId(String value) → Builder
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
uclid(String value) → Builder
videoDurationSec(double value) → Builder
videoViewSec(double value) → Builder

Operators

operator ==(Object other) → bool
The equality operator.
inherited