MethodHandler class

Constructors

MethodHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

invokeNativeMethod(String method, {Map<String, dynamic>? arguments, Duration timeout = const Duration(seconds: 30)}) → Future
Generic method to invoke any native method with standardized error handling.
invokeNativeMethodSafe(String method, {Map<String, dynamic>? arguments, Duration timeout = const Duration(seconds: 30), void onError(OsmosException)?}) → Future
Safe version that returns null on error instead of throwing.