OsmosException class

Custom exception class that maps to native platform errors

Implemented types

Constructors

OsmosException({required OsmosErrorCodes errorCode, String? details, dynamic nativeError})
const
OsmosException.fromError(dynamic error, {OsmosErrorCodes? fallbackErrorCode})
Create OsmosException from generic error
factory
OsmosException.fromPlatformException(PlatformException platformException)
Create OsmosException from PlatformException
factory

Properties

details → String?
final
errorCode → OsmosErrorCodes
final
hashCode → int
The hash code for this object.
no setterinherited
nativeError → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userMessage → String
Get user-friendly error message
no setter

Methods

isErrorType(OsmosErrorCodes type) → bool
Check if this is a specific error type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited