BannerAdViewManager class
Concrete implementation of BannerAdViewManagerInterface.
Manages the creation and configuration of banner advertisement widgets using the provided SDK configuration.
- Implemented types
Constructors
- BannerAdViewManager(OsmosConfig _config)
- Creates a BannerAdViewManager with the specified configuration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showAd(
{required Map< String, dynamic> adData, double? height, double? width, String? adLabelText, Alignment? adLabelAlignment, void onAdClick(Map)?, void onViewAppeared(Map, String)?}) → Widget -
Creates a banner ad widget with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited