PDAAdViewManager class
Concrete implementation of PDAAdViewManagerInterface.
Manages the creation and configuration of PDA advertisement widgets using the provided SDK configuration.
- Implemented types
Constructors
- PDAAdViewManager(OsmosConfig _config)
- Creates a PDAAdViewManager with the specified configuration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showAd(
{required Map< String, dynamic> adData, required PDAAdSettings settings}) → Widget -
Creates a PDA ad widget with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited