PIPAdViewManager class
Concrete implementation of PIPAdViewManagerInterface.
Manages the display and lifecycle of picture-in-picture advertisement views using the provided SDK configuration.
- Implemented types
Constructors
- PIPAdViewManager(OsmosConfig _config)
- Creates a PIPAdViewManager with the specified configuration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Disposes the current instance by canceling any active event subscriptions.
override
-
hidePip(
) → void -
Hides the currently displayed PIP ad.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resumePip(
{Duration delay = const Duration(milliseconds: 300)}) → void -
Resumes the PIP ad display after a specified delay.
override
-
showAd(
{required BuildContext context, required Map< String, dynamic> adData, int? width, int? height, int? x, int? y, String? adLabelText, Alignment? adLabelAlignment, void onAdClicked(Map? ad)?, void onAdAppeared(Map? ad, String? trackingId)?}) → Future<void> ? -
Displays a picture-in-picture ad with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited