SliderAdViewManager class
Concrete implementation of SliderAdViewManagerInterface.
Manages the display and lifecycle of slider advertisement views using the provided SDK configuration.
- Implemented types
Constructors
- SliderAdViewManager(OsmosConfig _config)
- Creates a SliderAdViewManager with the specified configuration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Disposes the current instance by canceling any active event subscriptions.
override
-
hideSlider(
) → void -
Hides the currently displayed slider ad.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resumeSlider(
) → void -
Resumes the currently displayed slider ad.
override
-
showAd(
{required BuildContext context, required Map< String, dynamic> adData, int? width, int? height, int? x, int? y, void onAdClicked(Map? ad)?, void onAdAppeared(Map? ad, String? trackingId)?}) → Future<void> ? -
Displays a slider ad with the specified configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited