PDAAdSettings class

PDA Ad Settings class matching iOS PDAAdSettings structure

Constructors

PDAAdSettings({double? width, double? height, PdaProductStyle adStyle = PdaProductStyle.vertical, String? adLabelText, Alignment adLabelAlignment = Alignment.topLeft, Widget? badge, dynamic adAppear(PdaAd)?, dynamic adClicked(PdaAd, CarouselCard?, String?)?, PDAAdCustomStyle? pdaAdCustomStyle})
const

Properties

adAppear → dynamic Function(PdaAd)?
final
adClicked → dynamic Function(PdaAd, CarouselCard?, String?)?
final
adLabelAlignment → Alignment
final
adLabelText → String?
final
adStyle → PdaProductStyle
final
badge → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
pdaAdCustomStyle → PDAAdCustomStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited