ConfigBuilder class

Constructors

ConfigBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Future<OsmosSDK>
buildGlobalInstance() → Future<void>
clientId(String clientId) → ConfigBuilder
debug([bool debug = true]) → ConfigBuilder
displayAdsHost(String displayAdsHost) → ConfigBuilder
enableBatchProcessing([bool enableBatchProcessing = false]) → ConfigBuilder
eventTrackingHost(String eventTrackingHost) → ConfigBuilder
maxEventsPerBatch([int? maxEventsPerBatch]) → ConfigBuilder
maxRetryCount([int? maxRetryCount]) → ConfigBuilder
maxTimeInterval([int? maxTimeInterval]) → ConfigBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
productAdsHost(String productAdsHost) → ConfigBuilder
shareAdvertisingId([bool shareAdvertisingId = true]) → ConfigBuilder
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited